#! /bin/sh

#unset http_proxy https_proxy ftp_proxy
echo "Now run /usr/local/bin/start.sh ..."

# Couchdb start
curl -L http://127.0.0.1:5984 || sudo /usr/local/etc/init.d/couchdb start
sleep 10 && curl -L http://127.0.0.1:5984 && echo "/usr/local/etc/init.d/couchdb start success" || echo "couchdb start still failed, check proxy...."

# PostgreSQL
DBHOST="localhost"
DBUSER="postgres"
POSTGRESQL_CONFIG="/etc/postgresql/10/main/postgresql.conf"
POSTGRESQL_DATA_DIR="/share/sw360_database/postgresql"
postgresql_data_directory=`grep "data_directory = '.*'" ${POSTGRESQL_CONFIG} | sed -r "s/.*'(.+)'.*/\1/"`
if [ "${postgresql_data_directory}" != "${POSTGRESQL_DATA_DIR}" ]; then
    if [ ! -d "${POSTGRESQL_DATA_DIR}" ];then
        sudo mkdir -p ${POSTGRESQL_DATA_DIR}
        if [ -f "/home/sw360/sw360_database.tar.bz2" ]; then
            echo "PostgreSQL: Use prepared database: sw360_database.tar.bz2."
            sudo tar -xjf /home/sw360/sw360_database.tar.bz2 -C /share
        else
            echo "PostgreSQL: Use original database: ${postgresql_data_directory}"
            sudo rsync -av ${postgresql_data_directory}"/" ${POSTGRESQL_DATA_DIR}
        fi
    fi
    sudo chown -R postgres:postgres ${POSTGRESQL_DATA_DIR}
    sudo chmod -R 700 ${POSTGRESQL_DATA_DIR}
    sudo sed -i -e "s/^data_directory = '.*'/data_directory = "\'$(echo ${POSTGRESQL_DATA_DIR} | sed -e 's/\//\\\//g')\'"/" ${POSTGRESQL_CONFIG}
    sudo pg_ctlcluster 10 main start
    psql -h"${DBHOST}" -U"${DBUSER}" -c"SHOW data_directory;"
fi
sudo pg_ctlcluster 10 main status | grep "pg_ctl: server is running" \
    && echo "PostgreSQL start success." \
    || sudo pg_ctlcluster 10 main start
sleep 20 && sudo pg_ctlcluster 10 main status | grep "pg_ctl: server is running" \
    && echo "PostgreSQL start success." \
    || echo "PostgreSQL start failed ..."

# PostgreSQL DB
db_name=`psql -h"${DBHOST}" -U"${DBUSER}" -c"select * from pg_database;" | awk '{if ($1=="lportal") print $1}'`
if [ -z $db_name ];then
    psql -h"${DBHOST}" -U"${DBUSER}" -c"CREATE DATABASE lportal;"
    psql -h"${DBHOST}" -U"${DBUSER}" -c"ALTER USER postgres WITH PASSWORD 'sw360fossy';"
fi

# Liferay
Liferay_log="/home/sw360/liferay/tomcat-9.0.17/logs/catalina.out"
echo "Liferay start ..."
(ps aux | grep tomcat | grep "org.apache.catalina.startup.Bootstrap start" && \
    sudo tail /home/sw360/liferay/tomcat-9.0.17/logs/catalina.out | grep "INFO \[main\] org.apache.catalina.startup.Catalina.start Server startup in \[.*,.*\] milliseconds") || \
    (sudo rm ${Liferay_log} && sudo /home/sw360/liferay/tomcat-9.0.17/bin/startup.sh)
# wait for 10min
for i in $(seq 1 120)
do
    sudo grep "INFO \[main\] org.apache.catalina.startup.Catalina.start Server startup in \[.*,.*\] milliseconds" ${Liferay_log} && break
    sleep 5
done
sudo grep "INFO \[main\] org.apache.catalina.startup.Catalina.start Server startup in \[.*,.*\] milliseconds" ${Liferay_log} \
    || echo "Wait for 10min and Liferay still not start, details for ${Liferay_log}"

# SW360tools
sw360_host="http://127.0.0.1:8080/"
sw360_app_properties="/home/sw360/SW360tools/src/main/resources/application.properties"
sed -i -e "s/^host.sw360=.*/host.sw360="\'$(echo ${sw360_host} | sed -e 's/\//\\\//g')\'"/" ${sw360_app_properties}

SW360tools_log="/home/sw360/SW360tools/logs/sw360tools.out"
cd /home/sw360/SW360tools
mvn tomcat7:run > logs/sw360tools.out 2>&1 &
sleep 20
grep "\[INFO\] BUILD FAILURE" ${SW360tools_log} && \
mvn clean install tomcat7:run > logs/sw360tools.out 2>&1 &
# wait for 30min
for i in $(seq 1 360)
do
    grep "INFO: Starting ProtocolHandler \[\"http-bio-8081\"\]" ${SW360tools_log} && break
    sleep 5
done
grep "INFO: Starting ProtocolHandler \[\"http-bio-8081\"\]" ${SW360tools_log} \
    || echo "Wait for 30min and sw360tools still not start, details for ${SW360tools_log}."

# Enbale the Import-Export function of the SPDX file.
cd ~
~/sw360/scripts/addUnsafeDefaultClient.sh